from Tkinter import *
from runner import *
from board import *

# Use for debugging
import tkMessageBox
def debug(message):
    tkMessageBox.showinfo("Debug", message)

class Suzuka():

    def __init__(self, master):
        # Draw controls
        Label(master, text="Competiters:").grid(row=0, column=0, sticky=W)
        self.competiters = Entry(master, width=3)
        self.competiters.insert(0, "1")
        self.competiters.grid(row=0, column=1)
        self.toggle = Button(master, text="Start", width=6, command=self.start_or_reset)
        self.toggle.grid(row=0, column=2)
        self.calibrate = Button(master, text="Calibrate", command=self.calibration)
        self.calibrate.grid(row=0, column=3, columnspan=4)
        self.clock = Label(master, text="00:00:00", font='Tahoma 30')
        self.clock.grid(row=1, column=0, columnspan=4)
        self.results = Listbox(master, width=36)
        self.results.grid(row=2, column=0, columnspan=4)

        # Initialize runner
        self.runner = None

    def start_or_reset(self):
        if self.runner is None:
            self.start()
        else:
            self.reset()

    def start(self):
        competiters = int(self.competiters.get())
        self.runner = Runner(self, competiters)
        self.runner.start()
        
        self.toggle.configure(text="Reset")

    def reset(self):
        self.runner.reset()
        self.runner = None

        # Reinitialize controls
        self.toggle.configure(text="Start")
        self.clock.configure(text = "00:00:00")
        self.results.delete(0, END)

    def calibration(self):
        board = BoardControl()
        tkMessageBox.showinfo("Calibration", "Do not point laser at the sensor, click OK.")
        normal = board.get_light()
        tkMessageBox.showinfo("Calibration", "Point laser at the sensor and click OK.")
        laser = board.get_light()
        tkMessageBox.showinfo("Calibration", "Calibration finished!\nNormal = %f\n Laser = %f" % (normal, laser))

        runner = Runner(self, 1)
        runner.calibrate(normal, laser)


root = Tk()
root.title("Suzuka")
suzuka = Suzuka(root)
root.mainloop()
